.. Sarge documentation master file, created by
   sphinx-quickstart on Thu Jan 19 18:01:03 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. _index:

Welcome to sarge's documentation!
=================================

Welcome to the documentation for ``sarge``, a wrapper for :mod:`subprocess`
which aims to make life easier for anyone who needs to interact with external
applications from their Python code.

**Please note:** this documentation is *work in progress*.

.. toctree::
   :maxdepth: 3

   overview
   tutorial
   internals
   reference
